@@ -18,18 +18,19 @@ import (
 	"context"
 	"sort"
 
-	"k8s.io/klog"
-
 	spokeClusterV1 "github.com/open-cluster-management/api/cluster/v1"
 	appv1alpha1 "github.com/stolostron/multicloud-operators-placementrule/pkg/apis/apps/v1"
 	"github.com/stolostron/multicloud-operators-placementrule/pkg/utils"
 	rbacv1 "k8s.io/api/authorization/v1"
 	"k8s.io/apimachinery/pkg/api/resource"
 	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/client-go/kubernetes"
+	"k8s.io/client-go/rest"
+	"k8s.io/klog"
 )
 
 func (r *ReconcilePlacementRule) hubReconcile(instance *appv1alpha1.PlacementRule) error {
-	clmap, err := utils.PlaceByGenericPlacmentFields(r.Client, instance.Spec.GenericPlacementFields, r.authClient, instance)
+	clmap, err := utils.PlaceByGenericPlacmentFields(r.Client, instance.Spec.GenericPlacementFields, instance)
 	if err != nil {
 		klog.Error("Error in preparing clusters by status:", err)
 		return err
@@ -290,9 +291,19 @@ func (r *ReconcilePlacementRule) filteClustersByIdentityAnno(instance *appv1alph
 		return nil
 	}
 
+	user, groups := utils.ExtractUserAndGroup(objanno)
+
+	userKubeConfig := r.authConfig
+	userKubeConfig.Impersonate = rest.ImpersonationConfig{
+		UserName: user,
+		Groups:   groups,
+	}
+
+	userKubeClient := kubernetes.NewForConfigOrDie(userKubeConfig)
+
 	for clusterName, cl := range clmap {
 		manageCluster := cl.DeepCopy()
-		if !r.checkUserPermission(objanno, manageCluster) {
+		if !r.checkUserPermission(userKubeClient, manageCluster, user, groups) {
 			delete(clmap, clusterName)
 		}
 	}
@@ -301,24 +312,22 @@ func (r *ReconcilePlacementRule) filteClustersByIdentityAnno(instance *appv1alph
 }
 
 // checkUserPermission checks if user can get managedCluster KIND resource.
-func (r *ReconcilePlacementRule) checkUserPermission(annotations map[string]string, managedCluster *spokeClusterV1.ManagedCluster) bool {
-	user, groups := utils.ExtractUserAndGroup(annotations)
+func (r *ReconcilePlacementRule) checkUserPermission(userKubeClient *kubernetes.Clientset, managedCluster *spokeClusterV1.ManagedCluster,
+	user string, groups []string) bool {
 	clusterName := managedCluster.GetName()
 
-	sar := &rbacv1.SubjectAccessReview{
-		Spec: rbacv1.SubjectAccessReviewSpec{
+	selfSAR := &rbacv1.SelfSubjectAccessReview{
+		Spec: rbacv1.SelfSubjectAccessReviewSpec{
 			ResourceAttributes: &rbacv1.ResourceAttributes{
 				Name:     clusterName,
 				Group:    "cluster.open-cluster-management.io",
 				Verb:     "get",
 				Resource: "managedclusters",
 			},
-			User:   user,
-			Groups: groups,
 		},
 	}
 
-	result, err := r.authClient.AuthorizationV1().SubjectAccessReviews().Create(context.TODO(), sar, v1.CreateOptions{})
+	result, err := userKubeClient.AuthorizationV1().SelfSubjectAccessReviews().Create(context.TODO(), selfSAR, v1.CreateOptions{})
 	klog.Infof("user: %v, groups: %v, cluster:%v, result:%v, err:%v", user, groups, clusterName, result, err)
 
 	if err != nil {
