@@ -25,7 +25,6 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/util/wait"
-	"k8s.io/client-go/kubernetes"
 	"k8s.io/klog"
 	"sigs.k8s.io/controller-runtime/pkg/client"
 
@@ -44,7 +43,7 @@ func ToPlaceLocal(placement *appv1alpha1.Placement) bool {
 // Top priority: clusterNames, ignore selector
 // Bottomline: Use label selector
 func PlaceByGenericPlacmentFields(kubeclient client.Client, placement appv1alpha1.GenericPlacementFields,
-	authclient kubernetes.Interface, object runtime.Object) (map[string]*spokeClusterV1.ManagedCluster, error) {
+	object runtime.Object) (map[string]*spokeClusterV1.ManagedCluster, error) {
 	clmap := make(map[string]*spokeClusterV1.ManagedCluster)
 
 	var labelSelector *metav1.LabelSelector
@@ -135,12 +134,13 @@ func IsReadyACMClusterRegistry(clReader client.Reader) bool {
 
 // DetectClusterRegistry - Detect the ACM cluster API service every 10 seconds. the controller will be exited when it is ready
 // The controller will be auto restarted by the multicluster-operators-application deployment CR later.
-func DetectClusterRegistry(clReader client.Reader, s <-chan struct{}) {
+//nolint:unparam
+func DetectClusterRegistry(ctx context.Context, clReader client.Reader) {
 	if !IsReadyACMClusterRegistry(clReader) {
-		go wait.Until(func() {
+		go wait.UntilWithContext(ctx, func(ctx context.Context) {
 			if IsReadyACMClusterRegistry(clReader) {
 				os.Exit(1)
 			}
-		}, time.Duration(10)*time.Second, s)
+		}, time.Duration(10)*time.Second)
 	}
 }
